[U-Boot] [PATCH 6/6] sh3/sh4: rename config option TMU_CLK_DIVIDER to CONFIG_SYS_TMU_CLK_DIV

Jean-Christophe PLAGNIOL-VILLARD plagnioj at jcrosoft.com
Thu Jun 4 12:06:48 CEST 2009


Signed-off-by: Jean-Christophe PLAGNIOL-VILLARD <plagnioj at jcrosoft.com>
Cc: Nobuhiro Iwamatsu <iwamatsu.nobuhiro at renesas.com>
---
 include/configs/MigoR.h     |    2 +-
 include/configs/ap325rxa.h  |    2 +-
 include/configs/mpr2.h      |    2 +-
 include/configs/ms7720se.h  |    2 +-
 include/configs/ms7722se.h  |    2 +-
 include/configs/ms7750se.h  |    2 +-
 include/configs/r2dplus.h   |    2 +-
 include/configs/r7780mp.h   |    2 +-
 include/configs/sh7763rdp.h |    2 +-
 include/configs/sh7785lcr.h |    2 +-
 lib_sh/time.c               |    4 ++--
 11 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/include/configs/MigoR.h b/include/configs/MigoR.h
index 6ef4c01..3853574 100644
--- a/include/configs/MigoR.h
+++ b/include/configs/MigoR.h
@@ -141,7 +141,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		(4)	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		(4)	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 #endif	/* __MIGO_R_H */
diff --git a/include/configs/ap325rxa.h b/include/configs/ap325rxa.h
index 550d67f..6f58a05 100644
--- a/include/configs/ap325rxa.h
+++ b/include/configs/ap325rxa.h
@@ -170,7 +170,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		(4)	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		(4)	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 #endif	/* __AP325RXA_H */
diff --git a/include/configs/mpr2.h b/include/configs/mpr2.h
index c147337..0a472a6 100644
--- a/include/configs/mpr2.h
+++ b/include/configs/mpr2.h
@@ -82,7 +82,7 @@
 
 /* Clocks */
 #define CONFIG_SYS_CLK_FREQ	24000000
-#define TMU_CLK_DIVIDER		4	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		4	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 /* UART */
diff --git a/include/configs/ms7720se.h b/include/configs/ms7720se.h
index f2e5122..ba0a3f8 100644
--- a/include/configs/ms7720se.h
+++ b/include/configs/ms7720se.h
@@ -101,7 +101,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		4	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		4	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 /* PCMCIA */
diff --git a/include/configs/ms7722se.h b/include/configs/ms7722se.h
index e83bd08..6755af3 100644
--- a/include/configs/ms7722se.h
+++ b/include/configs/ms7722se.h
@@ -128,7 +128,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		(4)	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		(4)	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 #endif	/* __MS7722SE_H */
diff --git a/include/configs/ms7750se.h b/include/configs/ms7750se.h
index 67af209..8c06bf2 100644
--- a/include/configs/ms7750se.h
+++ b/include/configs/ms7750se.h
@@ -101,7 +101,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		4
+#define CONFIG_SYS_TMU_CLK_DIV		4
 #define CONFIG_SYS_HZ		1000
 
 #endif /* __MS7750SE_H */
diff --git a/include/configs/r2dplus.h b/include/configs/r2dplus.h
index 804e3b8..25f5012 100644
--- a/include/configs/r2dplus.h
+++ b/include/configs/r2dplus.h
@@ -80,7 +80,7 @@
  * SuperH Clock setting
  */
 #define CONFIG_SYS_CLK_FREQ	60000000
-#define TMU_CLK_DIVIDER		4
+#define CONFIG_SYS_TMU_CLK_DIV		4
 #define CONFIG_SYS_HZ		1000
 #define	CONFIG_SYS_PLL_SETTLING_TIME	100/* in us */
 
diff --git a/include/configs/r7780mp.h b/include/configs/r7780mp.h
index 7b6867d..01b64e6 100644
--- a/include/configs/r7780mp.h
+++ b/include/configs/r7780mp.h
@@ -121,7 +121,7 @@
 
 /* Board Clock */
 #define CONFIG_SYS_CLK_FREQ	33333333
-#define TMU_CLK_DIVIDER		4
+#define CONFIG_SYS_TMU_CLK_DIV		4
 #define CONFIG_SYS_HZ		1000
 
 /* PCI Controller */
diff --git a/include/configs/sh7763rdp.h b/include/configs/sh7763rdp.h
index 79631be..c8c62ad 100644
--- a/include/configs/sh7763rdp.h
+++ b/include/configs/sh7763rdp.h
@@ -114,7 +114,7 @@
 
 /* Clock */
 #define CONFIG_SYS_CLK_FREQ	66666666
-#define TMU_CLK_DIVIDER		(4)	/* 4 (default), 16, 64, 256 or 1024 */
+#define CONFIG_SYS_TMU_CLK_DIV		(4)	/* 4 (default), 16, 64, 256 or 1024 */
 #define CONFIG_SYS_HZ		1000
 
 /* Ether */
diff --git a/include/configs/sh7785lcr.h b/include/configs/sh7785lcr.h
index 9b4defd..2c18e2f 100644
--- a/include/configs/sh7785lcr.h
+++ b/include/configs/sh7785lcr.h
@@ -186,7 +186,7 @@
 /* Board Clock */
 /* The SCIF used external clock. system clock only used timer. */
 #define CONFIG_SYS_CLK_FREQ	50000000
-#define TMU_CLK_DIVIDER		4
+#define CONFIG_SYS_TMU_CLK_DIV		4
 #define CONFIG_SYS_HZ		1000
 
 #endif	/* __SH7785LCR_H */
diff --git a/lib_sh/time.c b/lib_sh/time.c
index dc1c57e..52dbcd0 100644
--- a/lib_sh/time.c
+++ b/lib_sh/time.c
@@ -69,10 +69,10 @@ static void tmu_timer_stop (unsigned int timer)
 
 int timer_init (void)
 {
 	/* Divide clock by TMU_CLK_DIVIDER */
 	u16 bit = 0;
 
-	switch (TMU_CLK_DIVIDER) {
+	switch (CONFIG_SYS_TMU_CLK_DIV) {
 	case 1024:
 		bit = 4;
 		break;
@@ -69,10 +69,10 @@ static void tmu_timer_stop (unsigned int timer)
 int timer_init (void)
 {
-	/* Divide clock by TMU_CLK_DIVIDER */
+	/* Divide clock by CONFIG_SYS_TMU_CLK_DIV */
 	u16 bit = 0;
 
-- 
1.6.3.1



More information about the U-Boot mailing list